#python imports
from typing import Optional, List
import sqlite3

#dependency imports
from use_cases.user_repository import IUserRepository
from entities.user import User

class SQLUserRepository(IUserRepository):
    def __init__(self, db_file="framework_driver/db/shop.db"):
        """Initialize the UserDatabase with a connection to the SQLite database."""
        self.conn = sqlite3.connect(db_file)
        self.conn.row_factory = sqlite3.Row
    
    def create_user(self, user_name, user_email, user_password):
        """Add a new user to the users table and return the new user's id."""
        sql = "INSERT INTO users (name, email, password) VALUES (?, ?, ?)"
        try:
            c = self.conn.cursor()
            c.execute(sql, (user_name, user_email, user_password))
            self.conn.commit()
            return User(user_name, user_email, user_password, c.lastrowid)
        except sqlite3.Error as e:
            print(e)
            return None
